@@ -735,7 +735,7 @@ public class Copynumber {
 	    				String tumorQualities = "";
 
 	    				// Pileup Files have 6-7 columns //
-    					if(normalContents.length <= 7)
+    					if(normalContents.length >= 6 && normalContents.length <= 7)
     					{
     						pileupDepthNormal = Integer.parseInt(normalContents[3]);
     						normalQualities = normalContents[5];
@@ -748,7 +748,7 @@ public class Copynumber {
     					}
 
 	    				// Pileup Files have 6-7 columns //
-    					if(tumorContents.length <= 7)
+    					if(tumorContents.length >= 6 && tumorContents.length <= 7)
     					{
     						tumorQualities = tumorContents[5];
     						pileupDepthTumor = Integer.parseInt(tumorContents[3]);
