@@ -1,7 +1,7 @@
 /**
  * @(#)VarScan.java
  *
- * Copyright (c) 2009-2010 Daniel C. Koboldt and Washington University in St. Louis
+ * Copyright (c) 2009-2013 Daniel C. Koboldt and Washington University in St. Louis
  *
  * COPYRIGHT
  */
@@ -478,8 +478,8 @@ public class VarScan {
 	    		}
 	    		else
 	    		{
-    				System.err.println("File not found: " + args[1] + "\n");
-    				System.exit(10);
+//    				System.err.println("File not found: " + args[1] + "\n");
+//    				System.exit(10);
 	    		}
 	    	}
 
